@@ -16,11 +16,10 @@
 import warnings
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
 
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import grpc_helpers_async  # type: ignore
+from google.api_core import gapic_v1
+from google.api_core import grpc_helpers_async
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-import packaging.version
 
 import grpc  # type: ignore
 from grpc.experimental import aio  # type: ignore
@@ -205,8 +204,11 @@ class ClusterManagerGrpcAsyncIOTransport(ClusterManagerTransport):
         if not self._grpc_channel:
             self._grpc_channel = type(self).create_channel(
                 self._host,
+                # use the credentials which are saved
                 credentials=self._credentials,
-                credentials_file=credentials_file,
+                # Set ``credentials_file`` to ``None`` here as
+                # the credentials that we saved earlier should be used.
+                credentials_file=None,
                 scopes=self._scopes,
                 ssl_credentials=self._ssl_channel_credentials,
                 quota_project_id=quota_project_id,
@@ -1066,7 +1068,10 @@ class ClusterManagerGrpcAsyncIOTransport(ClusterManagerTransport):
     ]:
         r"""Return a callable for the set node pool size method over gRPC.
 
-        Sets the size for a specific node pool.
+        Sets the size for a specific node pool. The new size will be
+        used for all replicas, including future replicas created by
+        modifying
+        [NodePool.locations][google.container.v1.NodePool.locations].
 
         Returns:
             Callable[[~.SetNodePoolSizeRequest],
